---
title: ABC
description: Abstract Base Classes API reference
---

# ABC

This is where you can find all the Abstract Base Classes defined by arc. You generally shouldn't need to use/inherit from these classes directly, however most objects in arc derive from these, so they may be useful to you in some way.
